#
# spec file for package perl-GD
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name GD
Name:           perl-GD
Version:        2.830.0
Release:        1.3
# 2.83 -> normalize -> 2.830.0
%define cpan_version 2.83
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl interface to the libgd graphics library
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RU/RURBAN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         GD-cflags.patch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::Constant) >= 0.22
BuildRequires:  perl(ExtUtils::PkgConfig)
BuildRequires:  perl(File::Which)
BuildRequires:  perl(Test::Fork) >= 0.02
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::NoWarnings) >= 1.00
Provides:       perl(GD) = %{version}
Provides:       perl(GD::Group) = 1.00
Provides:       perl(GD::Image) = %{version}
Provides:       perl(GD::Polygon)
Provides:       perl(GD::Polyline) = 0.2
Provides:       perl(GD::Simple)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  gd-devel >= 2.0.28
Requires:       gd
# MANUAL END

%description
*GD.pm* is a Perl interface to Thomas Boutell's gd graphics library
(version 2.01 or higher; see below). GD allows you to create color drawings
using a large number of graphics primitives, and emit the drawings as PNG
files.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog const-c.inc const-xs.inc README README.QUICKDRAW
%license LICENSE

%changelog
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 2.830.0 (2.83)
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.83    * Fix missing PNG regression (RT #153923) on old
    systems without the .pc, but gdlib-config. The check was too strict.
    Requires now File::Which.
  2.82    * Improve HEIF/AVIF autodetection (RT #153305) by Yuriy Yevtukhov.
  * Fix strawberryperl default libgd path (shawnlaffan PR #54)
  * Fix AVIF and Webp autodetection in tests (shawnlaffan PR #54)
* Sat May  4 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.81
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.81    * Change GD::Polygon::transform to match old demos (RT #140043),
    and GD::Polyline.
    Add GD::Polygon::rotate(cw-radian) helper.
    Allow GD::Polygon::scale(2.0).
  2.80    * Fix broken copyTranspose and copyReverseTranspose (RT #153300)
    by Yuriy Yevtukhov.
  * Add transformation tests
  * Fix wrong WBMP name and detection
  * Fix wrong filename extension auto-detection for gd,gd2,wbmp
  * Fix wrong filename extension auto-detection for xpm,
    newFromXpm needs the filename, not handle.
  * Fix wrong libgd doc link (PR #52) by Tsuyoshi Watanabe
  2.79    * Improve image type autodetection (RT #153212), add a test
  * Fix Avif without Heif config
  * Improve gdlib.pc reader for supported library features
* Fri Jul  7 2023 Tina Müller <tina.mueller@suse.com>
- Updated GD-cflags.patch
* Wed Jul  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.78
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.78    * Fix Use of uninitialized value $pkg in concatenation warning
    (RT #148899 and GH #47). Thanks to ppisar for the analysis.
    Adds a new hard Test::NoWarnings test requirement.
  2.77    * add BMP support with libgd 2.1.0, PR #49 by PeterCJ
  * don't link to -lXPM without XPM nor X11, GH #45
  * rename ANIMGIF feature to GIFANIM
  * fix unused variable failure in GH CI, RT #141125 by PhilterPaper
* Thu May 11 2023 Dirk Stoecker <opensuse@dstoecker.de>
- update cpanspec.yml and recreate spec file
* Sun May  7 2023 Jan Engelhardt <jengelh@inai.de>
- Remove unused BuildRequires. Only gd is "#include"d.
* Wed Feb  2 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.76
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.76    * fix broken TIFF and AVIF support, PR #43 by Paul Howarth
  * re-enable XBM support (always on)
  * provide xbm magic support (a hack, for GD::Graph)
  2.75    * add experimental support for TIFF and RAQM (with freetype)
  * improve GD2 tests (GH #42, RT #140856)
  * also list the unsupported image formats in the GD::Image pod
  * fix copyRotated pod (it rotates CCW) PR #36 by LorenzoTo
  * fix GD::Simple->fontMetrics docs and implementation GH #37 by Ben Crowell.
    fix lineheight calculation according to the docs. You might need to
    fix your code!
  * add image methods tiff, webp, heif, avif, and its documentation.
  * fix the fix for the poly->transform documentation RT #140043
  2.74    * add experimental support for WEBP, HEIF and AVIF
  * document all supported Image formats in the GD::Image lib
  * added Github actions (for PR's)
  * fix poly->transform documentation RT #140043
  * fix GD,GD2 detection and tests RT #139399 (since libgd 2.3.3)
    fixed tests by Håkon Hægland.
  * POD: Remove indirect object constructors from example code snippet (PR #39)
  * patch from Ben Crowell that fixes incorrect behaviour of GD::Simple->fontMetrics
  * fix cross-compilation if gdlib.pc has no cflags by Fabrice Fontaine
* Tue Nov 10 2020 Pedro Monreal <pmonreal@suse.com>
- Remove not needed build requirement libvpx-devel [bsc#1173279]
* Fri Sep 25 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.73
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.73    * allow --options override the libgd options. Not recommended.
    See GH #33 and RT #130045
* Fri Jul 24 2020 Pedro Monreal <pmonreal@suse.com>
- Enable the test suite
* Sun Jul 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.72
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.72    * fix CVE 2019-6977 colorMatch for older unpatched libgd versions.
    This is a severe security problem, an exploitable heap-overflow.
    See https://nvd.nist.gov/vuln/detail/CVE-2019-6977
* Mon Jun 17 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- updated to 2.71
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.71    * skip Test::Fork on freebsd (GH #25)
  2.70    * fixes for hardened CCFLAGS with -Werror (RT #128167)
- Rebased patch GD-cflags.patch
- Enabled tests during build
- Updated URL to MetaCPAN
* Wed Sep 12 2018 pmonrealgonzalez@suse.com
- updated to 2.69
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.69    * little spelling error, GH #29 Xavier Guimard
  2.68    * fix GD::Polygon->clear, RT #124463 Michael Cain
  2.67    * fix thread-safety for GD::Simple %%COLORS (#26 melak)
  * fix arc start-angle docs, RT #123277 Andrew G Gray
  * improve setBrush docs, RT #123194 Andrew G Gray
  * improve StringFT docs, RT #123193
  * replace MacOSX by darwin, and not by Mac OS X/macOS as suggested
    in PR #24
  * add GD::Image->_file method as suggested in RT #60488 by Kevin Ryde,
    also the helper GD::supportsFileType
- Cleaned with spec-cleaner
* Mon Apr 24 2017 coolo@suse.com
- updated to 2.66
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.66    * throw proper error on newFrom* with not-existing file
  * add t/transp.t from RT #40525
  * Improve RT #54366 multiple gd.h warning
  * better doc for GD::Simple->arc
  * fix ANIMGIF with libgd 2.3.0-dev
  2.65    * fix --gdlib_config_path to accept an argument (fperrad)
  2.64    * Update doc for LIBGD_VERSION()
  * Fix 5.6.2, which does not have float in its typemap
  2.63    * renamed VERSION() to LIBGD_VERSION(), RT #121307.
    It was treated magically by "use GD 2.18"
  2.62    * fixed wrong <5.14 code generated with ExtUtils::Constants
    RT #121297. Don't generate const-xs.inc, only when missing.
  * add -liconv on hpux also (our pkgconfig parser cannot handle it)
  2.61    * add CONFIGURE_REQUIRES META
  * add --gdlib_config_path
  * add Image Filters: scatter, pixelate, negate, grayscale, brightness,
    contrast, color, selectiveBlur, edgeDetectQuick, gaussianBlur, emboss,
    meanRemoval, smooth, copyGaussianBlurred
  * add palette methods: createPaletteFromTrueColor,
    neuQuant (but discouraged), colorMatch.
  * add interpolation methods: copyScale, copyRotateInterpolated,
    interpolationMethod.
  * add double GD::VERSION
  * add all gd.h constants
  2.60    * add missing methods newFromWBMP, newFromXbm,
    (RT #68784) and some missing docs
  * Add --lib_fontconfig_path, --fcgi options
  * rewrote most of the XS code
  * cleanup Makefile.PL #20
  2.59    * error on failing libgd calls
  * fix colorClosestAlpha, colorAllocateAlpha
  * add missing documentation
  2.58    * fix VERSION_STRING for 2.0.x
  * honor --lib_gd_path specific gdlib-config
  * Loosen the comparison tests with GDIMAGETYPE ne gd2
  * Improve gdlib-config parsing (PR #17), esp. with 2.0.34
  2.57    * fix Jpeg magic number detection RT #26146
  * fix RGB - HSV roundtrips: RT #120572 by J2N-FORGET
  * fix -print-search-dirs errors RT #106265
  * co-maint to rurban
  * add hv_fetchs, CI smokers
  * add GD::VERSION_STRING api
  2.56_03 * add alpha method
  * improve option handling
  * fix meta data
  2.56_02 * fix feature extraction >= 2.2 [RT #119459]
  2.56_01 * rm Build.PL, fix permissions, fix for missing gdlib-config
* Sat Apr 18 2015 coolo@suse.com
- move /usr/bin/bdftogd to bdftogd.perl-gd to avoid conflict with
  gd package
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.56
  see /usr/share/doc/packages/perl-GD/ChangeLog
  2.56	* Fix Makefile.PL so that it works again.
  2.55	* Great simplification of regression framework ought to fix make test problems.
  * Replace ExtUtils::MakeMaker script with Module::Build system
  (just in time for Module::Build to be deprecated).
  * Remove archaic qd.pl (for creating QuickDraw picts) from distribution.
  2.54	Patch from yurly@unet.net to fix image corruption in rotate180 when image height is odd.
  2.53	Points to Gabor Szabo's GD::Simple tutorial, and fix link to repository.
  2.52    Fix regression tests to run on Ubuntu 12.04 64bit.
* Thu Oct 30 2014 darin@darins.net
- Added libtiff-devel and libvpx-devel to fix builds on SLE_12
* Sun Feb  9 2014 coolo@suse.com
- updated to 2.51
  Fix misleading warning message about location of gd.h file.
* Tue Dec 31 2013 coolo@suse.com
- disable test suite - comparing the bits of pngs is not good enough,
  debian and fedora have the same problem and no reaction upstream
  (RT#85789)
* Sat Jul 27 2013 coolo@suse.com
- updated to 2.50
  Fix gdUseFontConfig so that it can be called as a class method.
  Add GitHub information to README.
  Fix compile crash on windows and strawberry (https://rt.cpan.org/Public/Bug/Display.html?id=67990).
  Fix compilation on older perl's without the Newxz macros.
- rebased GD-cflags.patch
* Thu May 26 2011 coolo@novell.com
- do not add break perl structures in overwriting CCFLAGS with invalid
  flags
- regenerate with cpanspec 1.78.04
* Tue May  3 2011 vcizek@novell.com
- update to 2.46
  Added a basic "use" test for GD::Simple
  Corrected license to GPL+ or Artistic
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Jul 19 2010 anicka@suse.cz
- update to 2.45
  * Clarified the GD license. There is now a formal LICENSE file
  in the package.
* Tue Apr  6 2010 coolo@novell.com
- replace tests.tar with test10.png to fix only the test currently
  broken (relying on old libjpeg and libpng behaviour)
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Tue Jul 21 2009 chris@computersalat.de
- update to 2.44
  * GD::Group now installed properly.
  * Quenched compiler warning caused by Newxs() calls.
- 2.43
  * Added "transparent" color to GD::Simple.
  * Fixed Makefile so that GD/Image.pm depends both on GD/Image.pm.PLS and .config.cache
- 2.42
  * Fixed magic number detection to autodetect certain missed jpeg files (thanks to Mike Walker)
- added perl-macros
  o autogen filelist with perl_gen_filelist
* Wed Sep 10 2008 anicka@suse.cz
- update to 2.41
  * Added backend support for grouping features in GD::SVG module.
* Thu Jun 19 2008 anicka@suse.cz
- update to 2.39
  * Makefile.PL will refuse to run if the proper version of
  libgd is unavailable.
  * Fixed bizarre warning about
  /usr/include/gd.h != /usr/include/gd.h.
  * GD/Image.pm did not bring in croak() properly, meaning that
  incorrect error messages are printed out when any of the
  newFromXXX() calls are made.
  * Instructions on using gdAntiAliased with palette images.
  * Some instructions on installation for Windows users.
* Thu Sep 14 2006 anicka@suse.cz
- update to 2.35
  * Doesn't push libpng onto @LIBS unless png support is
    requested.
  * Supports Storable's freeze/thaw via a custom serializer.
  * Remove "scale redefined" message during compilation of
    Polyline.
* Thu Jul 13 2006 anicka@suse.cz
- update to 2.34
  * many bugfixes since 2.30 added
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update to 2.30
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Jul 29 2005 mjancar@suse.cz
- update to 2.25
* Sat Jan 22 2005 ro@suse.de
- update to 2.19, regenerate test pictures
* Tue Aug 24 2004 mjancar@suse.cz
- fix build with updated libpng
* Thu Aug 19 2004 mjancar@suse.cz
- update to 2.16
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.12
* Tue Jan 20 2004 meissner@suse.de
- regenerate test10.png so the testcases work.
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 24 2003 mjancar@suse.cz
- update to 2.07
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Apr 29 2003 mjancar@suse.cz
- update to version 2.06
- used $RPM_OPT_FLAGS
* Wed Dec 18 2002 prehak@suse.cz
- updated to version 2.05
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Jul 10 2002 prehak@suse.cz
- updated to version 1.40
- fixed some bugs in specfile
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri May  3 2002 meissner@suse.de
- %%_lib fixes.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan 30 2002 rvasice@suse.cz
- update to version 1.38
* Tue Sep  4 2001 rvasice@suse.cz
- fix Group tag to Development/Libraries/Perl
* Wed Aug 22 2001 rvasice@suse.cz
- update to version 1.33
- spec file cleanup
* Sun Aug 12 2001 kukuk@suse.de
- Fix path to perl interpreter
* Sat Apr 28 2001 ro@suse.de
- removed Requires and Obsoletes: gd (we have a package of that name)
* Thu Mar 22 2001 ro@suse.de
- use freetype2 with updated gd
- update to 1.32
* Thu Nov 16 2000 pblaha@suse.cz
- fix problem with #include <gd.h>
- and now requires gd
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild gdlib -> gd gd-devel
* Wed Nov  8 2000 pblaha@suse.cz
- rename to perl-GD
* Wed Oct  4 2000 pblaha@suse.cz
- updated to new version 1.30
* Tue Aug 22 2000 ro@suse.de
- fixed perl path
* Mon Jul 17 2000 nadvornik@suse.cz
- fixed neededforbuild
* Wed Jul 12 2000 bubnikv@suse.cz
- substitued /usr/local/bin/perl by /usr/bin/perl in some scripts
* Fri Jun  2 2000 nadvornik@suse.cz
- fixed /var/adm/perl-modules/gd
* Fri May 26 2000 bubnikv@suse.cz
- sorted
* Fri May 12 2000 nadvornik@suse.cz
- update to 1.27
- added BuildRoot
* Thu Jan 20 2000 aj@suse.de
- /usr/man -> /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sun Jul 11 1999 ro@suse.de
- fixed perl-path
* Tue Jun 15 1999 ro@suse.de
- update to 1.19
* Wed Mar 17 1999 ro@suse.de
- remove .orig with -f
* Wed Mar  3 1999 ro@suse.de
- filelist: use wildcard for arch in perl-path
* Tue Nov 17 1998 ro@suse.de
- adjust paths for perl 5.00502
* Thu Sep 24 1998 ro@suse.de
- respect perl-versions in spec-file-list
* Fri Aug 21 1998 ro@suse.de
- remove .origs in demos-dir
* Sun Jul 26 1998 bs@suse.de
- fixed pathes in perl scripts.
* Tue Feb 10 1998 bs@suse.de
- fixed Check for man pages
* Tue Jan 13 1998 bb@suse.de
  THE LATEST VERSION IS 1.15
  WHAT'S NEW IN 1.15
  - Patches from Ulrich Pfeifer to allow to compile
    correctly with FastCGI
  - Patches from Douglas Wegscheid to avoid multiple defined
    symbol problems under NetBSD
  - Patches from Weinfriend Koenig to fix problems in filled polygons,
    plus new routines for scaling, translating and rotating polygons.
